@@ -1,5 +1,6 @@
 # TODO do we use all these?
 import contextlib
+import glob
 import os
 import re
 import time
@@ -29,6 +30,13 @@ def is_plotting_cmdline(cmdline):
     )
 
 
+def is_plot_moving(cmdline):
+    return (
+            len(cmdline) > 3
+            and cmdline[0].endswith('plmo')
+    )
+
+
 # This is a cmdline argument fix for https://github.com/ericaltendorf/plotman/issues/41
 def cmdline_argfix(cmdline):
     known_keys = 'krbut2dnea'
@@ -102,6 +110,19 @@ class Job:
 
         return jobs
 
+    @staticmethod
+    def get_running_moving_jobs() -> list:
+        jobs = []
+
+        for proc in psutil.process_iter(['pid', 'cmdline']):
+            # Ignore processes which most likely have terminated between the time of iteration and data access.
+            with contextlib.suppress(psutil.NoSuchProcess, psutil.AccessDenied):
+                if is_plot_moving(proc.cmdline()):
+                    job = " ".join(proc.cmdline())
+                    jobs.append(job)
+
+        return jobs
+
     def __init__(self, proc, logroot):
         '''Initialize from an existing psutil.Process object.  must know logroot in order to understand open files'''
         self.proc = proc
@@ -348,6 +369,43 @@ class Job:
                 temp_files.add(f.path)
         return temp_files
 
+    def toJson(self) -> dict:
+        return dict(
+            plot_id=self.plot_id,
+            k=self.k,
+            r=self.r,
+            b=self.b,
+            u=self.u,
+            pid=self.proc.pid,
+            tmp=self.tmpdir,
+            tmp2=self.tmp2dir,
+            dst=self.dstdir,
+            plotid=self.plot_id,
+            logfile=self.logfile
+        )
+
+    @staticmethod
+    def get_jobs_json(jobs: list) -> dict:
+
+        count1 = len(glob.glob1("/mnt/local/tmp", "*.plot"))
+        count2 = len(glob.glob1("/mnt/local/temp", "*.plot"))
+
+        listplmo = Job.get_running_moving_jobs()
+
+        return dict(
+            jobls=[i.toJson() for i in jobs],
+            plotcount=count1 + count2,
+            movingcount=len(listplmo),
+            movingdetail=listplmo,
+            cpucount=psutil.cpu_count(),
+            info=psutil.cpu_stats()._asdict(),
+            perc=psutil.cpu_percent(),
+            vrm=psutil.virtual_memory(),
+            swap=psutil.swap_memory(),
+            disk=psutil.disk_partitions(),
+            net=psutil.net_io_counters(pernic=True),
+        )
+
     def cancel(self):
         'Cancel an already running job'
         # We typically suspend the job as the first action in killing it, so it
